@@ -24,7 +24,7 @@ import json
 
 import nbformat
 import json
-import constants
+import cortx_constants
 
 Config = namedtuple('Config', [
  'prefix', 'region', 'bucket_name', 'host_name', 'cortx_authenticator',
@@ -35,33 +35,33 @@ CredentialConfig = namedtuple('CredentialConfig', [
 ])
 
 
-# class ExpiringDict:
+class ExpiringDict:
 
-#     def __init__(self, seconds):
-#         self._seconds = seconds
-#         self._store = {}
+    def __init__(self, seconds):
+        self._seconds = seconds
+        self._store = {}
 
-#     def _remove_old_keys(self, now):
-#         self._store = {
-#             key: (expires, value)
-#             for key, (expires, value) in self._store.items()
-#             if expires > now
-#         }
+    def _remove_old_keys(self, now):
+        self._store = {
+            key: (expires, value)
+            for key, (expires, value) in self._store.items()
+            if expires > now
+        }
 
-#     def __getitem__(self, key):
-#         now = int(time.time())
-#         self._remove_old_keys(now)
-#         return self._store[key][1]
+    def __getitem__(self, key):
+        now = int(time.time())
+        self._remove_old_keys(now)
+        return self._store[key][1]
 
-#     def __setitem__(self, key, value):
-#         now = int(time.time())
-#         self._remove_old_keys(now)
-#         self._store[key] = (now + self._seconds, value)
+    def __setitem__(self, key, value):
+        now = int(time.time())
+        self._remove_old_keys(now)
+        self._store[key] = (now + self._seconds, value)
 
-#     def __delitem__(self, key):
-#         now = int(time.time())
-#         self._remove_old_keys(now)
-#         del self._store[key]
+    def __delitem__(self, key):
+        now = int(time.time())
+        self._remove_old_keys(now)
+        del self._store[key]
 
 
 # class Datetime(TraitType):
@@ -69,25 +69,19 @@ CredentialConfig = namedtuple('CredentialConfig', [
 #     default_value = datetime.datetime(1900, 1, 1)
 
 
-class CortxJupyterAuthentication(Configurable):
-
-    def get_credentials(self):
-        raise NotImplementedError()
-
-
-class CortxJupyterSecretAccessKeyAuthentication(CortxJupyterAuthentication):
-
-    aws_access_key_id = Unicode(config=True)
-    aws_secret_access_key = Unicode(config=True)
+class CortxAuthenticator(Configurable):
+    access_key_id = Unicode(config=True)
+    secret_access_key = Unicode(config=True)
 
     @gen.coroutine
     def get_credentials(self):
         return CredentialConfig(
-            access_key_id=self.aws_access_key_id,
-            secret_access_key=self.aws_secret_access_key,
+            access_key_id=self.access_key_id,
+            secret_access_key=self.secret_access_key,
         )
 
 
+
 class CortxJupyter(ContentsManager):
 
     bucket_name = Unicode(config=True)
@@ -96,8 +90,8 @@ class CortxJupyter(ContentsManager):
     prefix = Unicode(config=True)
     endpoint_url = Unicode(config=True)
 
-    authentication_class = Type(CortxJupyterAuthentication, config=True)
-    authentication = Instance(CortxJupyterAuthentication)
+    authentication_class = Type(CortxAuthenticator, config=True)
+    authentication = Instance(CortxAuthenticator)
 
     @default('authentication')
     def _default_authentication(self):
